<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * mod_debate data generator
 *
 * @package     mod_debate
 * @copyright   2021 Safat Shahin <safatshahin@gmail.com>
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

/**
 * data generator class for mod_debate
 *
 * @package     mod_debate
 * @copyright   2021 Safat Shahin <safatshahin@gmail.com>
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class mod_debate_generator extends testing_module_generator {

    /**
     * Creates a mod_debate instance
     * @param null $record
     * @param array|null $options
     * @return StdClass
     */
    public function create_instance($record = null, array $options = null) {
        $record = (object)(array)$record;
        $defaultsettings = array(
            'debateformat' => 0,
            'responsetype' => 0,
            'intro' => 'debate description',
            'introformat' => 1,
            'debateresponsecomcount' => 0
        );

        foreach ($defaultsettings as $name => $value) {
            if (!isset($record->{$name})) {
                $record->{$name} = $value;
            }
        }

        return parent::create_instance($record, (array)$options);
    }

    /**
     * Creates a debate response
     * @param $params
     */
    public function add_response($params){
        global $DB;
        $data = (object) [
            'courseid' => $params['courseid'],
            'debateid' => $params['debateid'],
            'userid' => $params['userid'],
            'response' => 'test response from user:'.$params['userid'],
            'responsetype' => $params['responsetype']
        ];
        $DB->insert_record('debate_response', $data);
    }

    /**
     * Creates a debate team
     * @param $params
     */
    public function create_team($params) {
        global $DB;
        $params = (object) $params;
        $data = (object) [
            'name' => 'test debate team',
            'responsetype' => 1,
            'responseallowed' => 2,
            'active' => 1
        ];

        foreach ($data as $name => $value) {
            if (!isset($params->{$name})) {
                $params->{$name} = $value;
            }
        }
        $DB->insert_record('debate_teams', $params);
    }

}
